@@ -25,7 +25,7 @@ translation_copyrights="English, German: George Ruinelli\n"+\
                                      "Chinese: "+(u'蒋岚')+" (Peter3316)"
 
 #DEFAULT VALUES
-Yscale_Movement_default=40  #Y stretching of yellow movement bars
+Yscale_Movement_default=20  #Y stretching of yellow movement bars
 DelayStartTime_default=10 #Default recording start delay
 Yscale_Sleep_Pattern_default=40 #Y stretching of blue sleep pattern
 Yoffset_Sleep_Pattern_default= 0  #Y offset of blue sleep pattern
@@ -36,7 +36,6 @@ Deep_Sleep_Level_default=35
 configFileVersion=4 #increase if parameters have changed
 
 
-
 GraphBitMap=""
 GraphBitMapLen=0
 GraphBitMapHeight=0
@@ -150,8 +149,10 @@ GraphBackground2="#2B2B2B"
 #Colors for time bars
 Deep_Sleep_Color=       "#00C800" #green
 Deep_Sleep_ColorDark="#003200"
-Light_Sleep_Color=        "#006400" #darker green
-Light_Sleep_ColorDark= "#001400"
+#Light_Sleep_Color=        "#006400" #darker green
+#Light_Sleep_ColorDark= "#001400"
+Light_Sleep_Color=        "#D87519" #darker green
+Light_Sleep_ColorDark= "#3D370A"
 Awake_Color=                "#860000" #red
 Awake_ColorDark=         "#4C0000"
 
